==> apo-ws-client-6.00.10.1-sources.jar: fr/univlorraine/apowsclient/creationSE/CreerVET.java <==

package fr.univlorraine.apowsclient.creationSE;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour anonymous complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType&gt;
 *   &lt;complexContent&gt;
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType"&gt;
 *       &lt;sequence&gt;
 *         &lt;element name="versionEtape" type="{VersionEtapeDTO.creerse.offreformation.dto.transverse.commun.apogee.education.gouv}VersionEtapeDTO" form="unqualified"/&gt;
 *       &lt;/sequence&gt;
 *     &lt;/restriction&gt;
 *   &lt;/complexContent&gt;
 * &lt;/complexType&gt;
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "versionEtape"
})
@XmlRootElement(name = "creerVET", namespace = "gouv.education.apogee.commun.servicesmetiers.CreationSEMetier_17102019")
public class CreerVET {

    @XmlElement(required = true)
    protected VersionEtapeDTO versionEtape;

    /**
     * Obtient la valeur de la propriété versionEtape.
     * 
     * @return
     *     possible object is
     *     {@link VersionEtapeDTO }
     *     
     */
    public VersionEtapeDTO getVersionEtape() {
        return versionEtape;
    }

    /**
     * Définit la valeur de la propriété versionEtape.
     * 
     * @param value
     *     allowed object is
     *     {@link VersionEtapeDTO }
     *     
     */
    public void setVersionEtape(VersionEtapeDTO value) {
        this.versionEtape = value;
    }

}

==> apo-ws-client-6.00.51.1-sources.jar: fr/univlorraine/apowsclient/creationSE/CreerVET.java <==

package fr.univlorraine.apowsclient.creationSE;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour anonymous complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType&gt;
 *   &lt;complexContent&gt;
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType"&gt;
 *       &lt;sequence&gt;
 *         &lt;element name="versionEtape" type="{VersionEtapeDTO.creerse.offreformation.dto.transverse.commun.apogee.education.gouv}VersionEtapeDTO" form="unqualified"/&gt;
 *       &lt;/sequence&gt;
 *     &lt;/restriction&gt;
 *   &lt;/complexContent&gt;
 * &lt;/complexType&gt;
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "versionEtape"
})
@XmlRootElement(name = "creerVET", namespace = "gouv.education.apogee.commun.servicesmetiers.CreationSEMetier")
public class CreerVET {

    @XmlElement(required = true)
    protected VersionEtapeDTO versionEtape;

    /**
     * Obtient la valeur de la propriété versionEtape.
     * 
     * @return
     *     possible object is
     *     {@link VersionEtapeDTO }
     *     
     */
    public VersionEtapeDTO getVersionEtape() {
        return versionEtape;
    }

    /**
     * Définit la valeur de la propriété versionEtape.
     * 
     * @param value
     *     allowed object is
     *     {@link VersionEtapeDTO }
     *     
     */
    public void setVersionEtape(VersionEtapeDTO value) {
        this.versionEtape = value;
    }

}
